==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/tr-TR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Toplu varlık silmeyi onaylıyor musunuz?',
    'bulk_restore'      => 'Toplu varlık geriyüklemesini onaylayın', 
  'bulk_delete_help'	=> 'Toplu silme için aşağıdaki Varlıkları gözden geçirin. Silindikten sonra bu varlıkların geri yüklenebilir fakat atanmış olan herhangi bir kullanıcı ile ilişkili olmayacaktır.',
  'bulk_restore_help'	=> 'Aşağıdaki varlık geri yüklemesini gözden geçirin. Geri yüklendiklerinde saha önceden atanmış olan sahiplerine dair aitlikleri kalmayacaktır.',
  'bulk_delete_warn'	=> ':asset_count adet varlığı düzenlemek üzeresiniz.',
  'bulk_restore_warn'	=> 'Geri yüklüyorsunuz : asset_count assets.',
    'bulk_update'		=> 'Demirbaşları Toplu Güncelle',
    'bulk_update_help'	=> 'Bu form birden çok demirbaşı tek seferde güncellemenizi sağlar. Lütfen sadece değiştirmek istediğiniz alanları doldurunuz. Değiştirilmesini istemediğiniz alanları boş bırakınız. ',
    'bulk_update_warn'	=> 'Tek bir varlığın özelliklerini düzenlemek üzeresiniz.| :asset_count varlıkların özelliklerini düzenlemek üzeresiniz.',
    'bulk_update_with_custom_field' => 'Varlıkların farklı model türleri olduğunu unutmayın :asset_model_count',
    'bulk_update_model_prefix' => 'Modellerde', 
    'bulk_update_custom_field_unique' => 'Bu benzersiz bir alandır (satırdır, hücredir), Toplu şekilde düzenleyemezsiniz.',
    'checkedout_to'		=> 'Çıkış Yapılmış Olan Kişi',
    'checkout_date'		=> 'Çıkış Tarihi',
    'checkin_date'		=> 'Giriş Tarihi',
    'checkout_to'		=> 'Çıkış Yapılacak Kişi',
    'cost'				=> 'Satın Alma Ücreti',
    'create'			=> 'Demirbaş Oluştur',
    'date'				=> 'Satın Alma Tarihi',
    'depreciation'	    => 'Amortisman',
    'depreciates_on'	=> 'Amortisman',
    'default_location'	=> 'Varsayılan Konum',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Ömür',
    'eol_rate'			=> 'Ömür Başarısı',
    'expected_checkin'  => 'Beklenen geri alma tarihi',
    'expires'			=> 'Son kullanma tarihi',
    'fully_depreciated'	=> 'Değeri tamamen düştü',
    'help_checkout'		=> 'Bu varlığı hemen atamak istiyorsanız Durum listesinden "Atanabilir" durumunu seçin. ',
    'mac_address'		=> 'MAC Adresi',
    'manufacturer'		=> 'Üretici',
    'model'				=> 'Model',
    'months'			=> 'ay',
    'name'				=> 'Demirbaş Adı',
    'notes'				=> 'Notlar',
    'order'				=> 'Sipariş Numarası',
    'qr'				=> 'QR Kod',
    'requestable'		=> 'Kullanıcılar bu demirbaşı talep edebilir',
    'select_statustype'	=> 'Durum Seçiniz',
    'serial'			=> 'Seri No',
    'status'			=> 'Durum',
    'tag'				=> 'Demirbaş Etiketi',
    'update'			=> 'Demirbaş Güncelle',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garanti Süresi Sona Erdi',
    'years'				=> 'yıl',
    'asset_location' => 'Varlık konumunu güncelle',
    'asset_location_update_default_current' => 'Varsayılan konumu ve gerçek konumu güncelle',
    'asset_location_update_default' => 'Sadece varsayılan konumu güncelle',
    'asset_location_update_actual' => 'Sadece geçerli konumu güncelle',
    'asset_not_deployable' => 'Bu demirbaş dağıtılabilir durumda değil. Çıkışı yapılamaz.',
    'asset_deployable' => 'Bu demirbaş dağıtılabilir durumda. Çıkışı yapılabilir.',
    'processing_spinner' => 'İşleniyor... (Büyük dosyalarda bu işlem biraz zaman alabilir)',
    'optional_infos'  => 'Opsiyonel Bilgi',
    'order_details'   => 'Sipariş Bilgileri'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/tr-TR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Toplu varlık silmeyi onaylıyor musunuz?',
    'bulk_restore'      => 'Toplu varlık geriyüklemesini onaylayın', 
  'bulk_delete_help'	=> 'Toplu silme için aşağıdaki Varlıkları gözden geçirin. Silindikten sonra bu varlıkların geri yüklenebilir fakat atanmış olan herhangi bir kullanıcı ile ilişkili olmayacaktır.',
  'bulk_restore_help'	=> 'Aşağıdaki varlık geri yüklemesini gözden geçirin. Geri yüklendiklerinde saha önceden atanmış olan sahiplerine dair aitlikleri kalmayacaktır.',
  'bulk_delete_warn'	=> ':asset_count adet varlığı düzenlemek üzeresiniz.',
  'bulk_restore_warn'	=> 'Geri yüklüyorsunuz : asset_count assets.',
    'bulk_update'		=> 'Demirbaşları Toplu Güncelle',
    'bulk_update_help'	=> 'Bu form birden çok demirbaşı tek seferde güncellemenizi sağlar. Lütfen sadece değiştirmek istediğiniz alanları doldurunuz. Değiştirilmesini istemediğiniz alanları boş bırakınız. ',
    'bulk_update_warn'	=> 'Tek bir varlığın özelliklerini düzenlemek üzeresiniz.| :asset_count varlıkların özelliklerini düzenlemek üzeresiniz.',
    'bulk_update_with_custom_field' => 'Varlıkların farklı model türleri olduğunu unutmayın :asset_model_count',
    'bulk_update_model_prefix' => 'Modellerde', 
    'bulk_update_custom_field_unique' => 'Bu benzersiz bir alandır (satırdır, hücredir), Toplu şekilde düzenleyemezsiniz.',
    'checkedout_to'		=> 'Çıkış Yapılmış Olan Kişi',
    'checkout_date'		=> 'Çıkış Tarihi',
    'checkin_date'		=> 'Giriş Tarihi',
    'checkout_to'		=> 'Çıkış Yapılacak Kişi',
    'cost'				=> 'Satın Alma Ücreti',
    'create'			=> 'Demirbaş Oluştur',
    'date'				=> 'Satın Alma Tarihi',
    'depreciation'	    => 'Amortisman',
    'depreciates_on'	=> 'Amortisman',
    'default_location'	=> 'Varsayılan Konum',
    'default_location_phone' => 'Varsayılan Konum Telefonu',
    'eol_date'			=> 'Ömür',
    'eol_rate'			=> 'Ömür Başarısı',
    'expected_checkin'  => 'Beklenen geri alma tarihi',
    'expires'			=> 'Son kullanma tarihi',
    'fully_depreciated'	=> 'Değeri tamamen düştü',
    'help_checkout'		=> 'Bu varlığı hemen atamak istiyorsanız Durum listesinden "Atanabilir" durumunu seçin. ',
    'mac_address'		=> 'MAC Adresi',
    'manufacturer'		=> 'Üretici',
    'model'				=> 'Model',
    'months'			=> 'ay',
    'name'				=> 'Demirbaş Adı',
    'notes'				=> 'Notlar',
    'order'				=> 'Sipariş Numarası',
    'qr'				=> 'QR Kod',
    'requestable'		=> 'Kullanıcılar bu demirbaşı talep edebilir',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Durum Seçiniz',
    'serial'			=> 'Seri No',
    'status'			=> 'Durum',
    'tag'				=> 'Demirbaş Etiketi',
    'update'			=> 'Demirbaş Güncelle',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garanti Süresi Sona Erdi',
    'years'				=> 'yıl',
    'asset_location' => 'Varlık konumunu güncelle',
    'asset_location_update_default_current' => 'Varsayılan konumu ve gerçek konumu güncelle',
    'asset_location_update_default' => 'Sadece varsayılan konumu güncelle',
    'asset_location_update_actual' => 'Sadece geçerli konumu güncelle',
    'asset_not_deployable' => 'Bu demirbaş dağıtılabilir durumda değil. Çıkışı yapılamaz.',
    'asset_deployable' => 'Bu demirbaş dağıtılabilir durumda. Çıkışı yapılabilir.',
    'processing_spinner' => 'İşleniyor... (Büyük dosyalarda bu işlem biraz zaman alabilir)',
    'optional_infos'  => 'Opsiyonel Bilgi',
    'order_details'   => 'Sipariş Bilgileri'
];
